==> griddle-0.0.1.tgz: package/index.js <==
var fs = require('fs');
var path = require('path');
var handlebars = require('handlebars');
var GulpProject = require('./gulp-project');

var template = handlebars.compile(fs.readFileSync(
      path.resolve(__dirname, 'views', 'error.handlebars')).toString());

function error(response, error, errorTemplate) {
  var e = {
    title: 'Build Error',
    error: error
  };
  response.status(500);
  if(errorTemplate) {
    response.render(errorTemplate, e);
  } else {
    response.send(template(e));
  }
}

module.exports = function(src, watch, errorTemplate) {
  var gp = new GulpProject(src);

  // Always kick off an initial build
  gp.build();

  // If we're supposed to, kick off a build whenever anything
  // changes.
  if(watch !== false) {
    fs.watch(gp.paths.src, gp.build.bind(gp));
  }

  return function(request, response, next) {
    switch(gp.status()) {
      case GulpProject.Status.BUILDING:
        var success = function() {
          gp.removeListener(GulpProject.Event.BUILD_FAILED, failed);
          next();
        };
        var failed = function() {
          gp.removeListener(GulpProject.Event.BUILD_SUCCESSFUL, success);
          error(response, gp.error, errorTemplate);
        };
        gp.once(GulpProject.Event.BUILD_SUCCESSFUL, success);
        gp.once(GulpProject.Event.BUILD_FAILED, failed);
        break;
      case GulpProject.Status.LAST_BUILD_FAILED:
        error(response, gp.error, errorTemplate);
        break;
      default:
        next();
    }
  };
};

==> griddle-0.0.2.tgz: package/index.js <==
var fs = require('fs');
var path = require('path');
var handlebars = require('handlebars');
var GulpProject = require('./gulp-project');

var template = handlebars.compile(fs.readFileSync(
      path.resolve(__dirname, 'views', 'error.handlebars')).toString());

function respondWithError(response, error, errorTemplate) {
  var e = {
    title: 'Build Error',
    error: error
  };
  response.status(500);
  if(errorTemplate) {
    response.render(errorTemplate, e);
  } else {
    response.send(template(e));
  }
}

module.exports = function(src, watch, errorTemplate) {
  var gp = new GulpProject(src);

  // Always kick off an initial build
  gp.build();

  // If we're supposed to, kick off a build whenever anything
  // changes.
  if(watch !== false) {
    fs.watch(gp.paths.src, gp.build.bind(gp));
  }

  return function(request, response, next) {
    switch(gp.status()) {
      case GulpProject.Status.BUILDING:
        var success = function() {
          gp.removeListener(GulpProject.Event.BUILD_FAILED, failed);
          next();
        };
        var failed = function() {
          gp.removeListener(GulpProject.Event.BUILD_SUCCESSFUL, success);
          respondWithError(response, gp.error, errorTemplate);
        };
        gp.once(GulpProject.Event.BUILD_SUCCESSFUL, success);
        gp.once(GulpProject.Event.BUILD_FAILED, failed);
        break;
      case GulpProject.Status.LAST_BUILD_FAILED:
        respondWithError(response, gp.error, errorTemplate);
        break;
      default:
        next();
    }
  };
};
